@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
-our $DATE = '2016-02-03'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2016-10-22'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -52,7 +52,7 @@ sub GetOptionsWithCompletion {
             ($words,$cword) = @{ Complete::Bash::join_wordbreak_words($words, $cword) };
         } elsif ($ENV{COMMAND_LINE}) {
             require Complete::Tcsh;
-            $shell = 'tcsh';
+            $shell //= 'tcsh';
             ($words, $cword) = @{ Complete::Tcsh::parse_cmdline() };
         }
 
@@ -66,10 +66,19 @@ sub GetOptionsWithCompletion {
         );
 
         if ($shell eq 'bash') {
+            require Complete::Bash;
+            print Complete::Bash::format_completion(
+                $compres, {word=>$words->[$cword]});
+        } elsif ($shell eq 'fish') {
+            require Complete::Fish;
             print Complete::Bash::format_completion(
                 $compres, {word=>$words->[$cword]});
         } elsif ($shell eq 'tcsh') {
+            require Complete::Tcsh;
             print Complete::Tcsh::format_completion($compres);
+        } elsif ($shell eq 'zsh') {
+            require Complete::Zsh;
+            print Complete::Zsh::format_completion($compres);
         } else {
             die "Unknown shell '$shell'";
         }
@@ -111,7 +120,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.27 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-02-03.
+This document describes version 0.28 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-10-22.
 
 =head1 SYNOPSIS
 
@@ -263,7 +272,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Complete>.
+Source repository is at L<https://github.com/sharyanto/perl-Getopt-Long-Complete>.
 
 =head1 BUGS
 
